#ifndef FEATURES_H
#define FEATURES_H

/* GNU libc */
#define _GNU_SOURCE

/* Solaris */
#define __EXTENSIONS__

/* stdint.h, inttypes.h */
#define __STDC_LIMIT_MACROS
#define __STDC_CONSTANT_MACROS
#define __STDC_FORMAT_MACROS

#endif /* FEATURES_H */
